<?php

namespace Eform\Faq\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Eform\Faq\Actions\FaqAction;
use Eform\Faq\Http\Requests\FaqActionRequest;
use Eform\Faq\Http\Resources\FaqResource;
use Eform\Faq\Models\Faq;

/**
 * Admin web controller class.
 */
class FaqActionController extends BaseController
{

    /**
     * Action controller function for faq.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(FaqActionRequest $request, Faq $faq, $action)
    {
        try {
            $request = $request->all();
            $faq = FaqAction::run($action, $faq, $request);

            $data = new FaqResource($faq);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('faq::faq.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('faq/faq/' . $faq->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('faq/faq/' . $faq->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
