<?php

namespace Eform\Faq\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Eform\Faq\Http\Resources\FaqResource;
use Eform\Faq\Http\Resources\FaqsCollection;
use Eform\Faq\Scopes\FaqPublicScope;
use Eform\Faq\Models\Faq;

class FaqPublicController extends BaseController
{

    /**
     * Show faq's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Faq::pushScope(new RequestScope())
            ->pushScope(new FaqPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $faqs = new FaqsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('faq::faq.names'))
            ->view('faq::public.faq.index')
            ->data(compact('faqs', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show faq.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Faq::findBySlug($slug);
        $data = new FaqResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('faq::faq.name'))
            ->view('faq::public.faq.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
